@@ -1,10 +1,24 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * e-cell-checkbox.c: Checkbox cell renderer
+ * Copyright 1999, 2000, Ximian, Inc.
  *
- * Author:
- *   Miguel de Icaza (miguel@kernel.org)
+ * Authors:
+ *   Miguel de Icaza <miguel@ximian.com>
  *
- * (C) 1999, 2000 Ximian, Inc
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 #include <config.h>
 #include <gtk/gtkenums.h>
@@ -12,7 +26,7 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtksignal.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-canvas.h>
+#include <libgnomecanvas/gnome-canvas.h>
 #include "e-cell-checkbox.h"
 #include "gal/util/e-util.h"
 #include "e-table-item.h"
@@ -31,7 +45,7 @@ e_cell_checkbox_class_init (GtkObjectClass *object_class)
 	checks [1] = gdk_pixbuf_new_from_xpm_data (check_filled_xpm);
 }
 
-E_MAKE_TYPE(e_cell_checkbox, "ECellCheckbox", ECellCheckbox, e_cell_checkbox_class_init, NULL, PARENT_TYPE);
+E_MAKE_TYPE(e_cell_checkbox, "ECellCheckbox", ECellCheckbox, e_cell_checkbox_class_init, NULL, PARENT_TYPE)
 
 /**
  * e_cell_checkbox_new:
