@@ -33,6 +33,7 @@
 #include "gal/e-table/e-cell-size.h"
 #include "gal/e-table/e-cell-tree.h"
 #include "e-table-extras.h"
+#include <string.h>
 
 #define PARENT_TYPE (gtk_object_get_type())
 
@@ -73,6 +74,11 @@ ete_destroy (GtkObject *object)
 		g_hash_table_destroy (ete->compares);
 	}
 
+	if (ete->searches) {
+		g_hash_table_foreach (ete->searches, (GHFunc) g_free, NULL);
+		g_hash_table_destroy (ete->searches);
+	}
+
 	if (ete->pixbufs) {
 		g_hash_table_foreach (ete->pixbufs, (GHFunc) pixbuf_hash_free, NULL);
 		g_hash_table_destroy (ete->pixbufs);
@@ -80,6 +86,7 @@ ete_destroy (GtkObject *object)
 
 	ete->cells = NULL;
 	ete->compares = NULL;
+	ete->searches = NULL;
 	ete->pixbufs = NULL;
 
 	GTK_OBJECT_CLASS (ete_parent_class)->destroy (object);
@@ -102,17 +109,68 @@ e_strint_compare(gconstpointer data1, gconstpointer data2)
 	return g_int_compare(GINT_TO_POINTER(int1), GINT_TO_POINTER(int2));
 }
 
+/* UTF-8 strncasecmp - not optimized */
+
+static gint
+g_utf8_strncasecmp (const gchar *s1,
+		    const gchar *s2,
+		    guint n)
+{
+	gunichar c1, c2;
+
+	g_return_val_if_fail (s1 != NULL && g_utf8_validate (s1, -1, NULL), 0);
+	g_return_val_if_fail (s2 != NULL && g_utf8_validate (s2, -1, NULL), 0);
+
+	while (n && *s1 && *s2)
+		{
+
+			n -= 1;
+
+			c1 = g_unichar_tolower (g_utf8_get_char (s1));
+			c2 = g_unichar_tolower (g_utf8_get_char (s2));
+
+			/* Collation is locale-dependent, so this totally fails to do the right thing. */
+			if (c1 != c2)
+				return c1 < c2 ? -1 : 1;
+
+			s1 = g_utf8_next_char (s1);
+			s2 = g_utf8_next_char (s2);
+		}
+
+	if (n == 0 || (*s1 == '\0' && *s2 == '\0'))
+		return 0;
+
+	return *s1 ? 1 : -1;
+}
+
+static gboolean
+e_string_search(gconstpointer haystack, const char *needle)
+{
+	int length;
+	if (haystack == NULL)
+		return FALSE;
+
+	length = g_utf8_strlen (needle, -1);
+	if (g_utf8_strncasecmp (haystack, needle, length) == 0)
+		return TRUE;
+	else
+		return FALSE;
+}
+
 static void
 ete_init (ETableExtras *extras)
 {
 	extras->cells = g_hash_table_new(g_str_hash, g_str_equal);
 	extras->compares = g_hash_table_new(g_str_hash, g_str_equal);
+	extras->searches = g_hash_table_new(g_str_hash, g_str_equal);
 	extras->pixbufs = g_hash_table_new(g_str_hash, g_str_equal);
 
 	e_table_extras_add_compare(extras, "string", g_str_compare);
 	e_table_extras_add_compare(extras, "integer", g_int_compare);
 	e_table_extras_add_compare(extras, "string-integer", e_strint_compare);
 
+	e_table_extras_add_search(extras, "string", e_string_search);
+
 	e_table_extras_add_cell(extras, "checkbox", e_cell_checkbox_new());
 	e_table_extras_add_cell(extras, "date", e_cell_date_new (NULL, GTK_JUSTIFY_LEFT));
 	e_table_extras_add_cell(extras, "number", e_cell_number_new (NULL, GTK_JUSTIFY_RIGHT));
@@ -122,7 +180,7 @@ ete_init (ETableExtras *extras)
 	e_table_extras_add_cell(extras, "tree-string", e_cell_tree_new (NULL, NULL, TRUE, e_cell_text_new (NULL, GTK_JUSTIFY_LEFT)));
 }
 
-E_MAKE_TYPE(e_table_extras, "ETableExtras", ETableExtras, ete_class_init, ete_init, PARENT_TYPE);
+E_MAKE_TYPE(e_table_extras, "ETableExtras", ETableExtras, ete_class_init, ete_init, PARENT_TYPE)
 
 ETableExtras *
 e_table_extras_new (void)
@@ -169,19 +227,42 @@ e_table_extras_add_compare  (ETableExtras *extras,
 	gchar *old_key;
 	GCompareFunc old_compare;
 
-	if (g_hash_table_lookup_extended (extras->cells, id, (gpointer *)&old_key, (gpointer *)&old_compare)) {
-		g_hash_table_remove (extras->cells, old_key);
+	if (g_hash_table_lookup_extended (extras->compares, id, (gpointer *)&old_key, (gpointer *)&old_compare)) {
+		g_hash_table_remove (extras->compares, old_key);
 		g_free (old_key);
 	}
 
-	g_hash_table_insert(extras->compares, g_strdup(id), compare);
+	g_hash_table_insert(extras->compares, g_strdup(id), (gpointer) compare);
 }
 
 GCompareFunc
 e_table_extras_get_compare  (ETableExtras *extras,
 			     char         *id)
 {
-	return g_hash_table_lookup(extras->compares, id);
+	return (GCompareFunc) g_hash_table_lookup(extras->compares, id);
+}
+
+void
+e_table_extras_add_search  (ETableExtras     *extras,
+			    char             *id,
+			    ETableSearchFunc  search)
+{
+	gchar *old_key;
+	ETableSearchFunc old_search;
+
+	if (g_hash_table_lookup_extended (extras->searches, id, (gpointer *)&old_key, (gpointer *)&old_search)) {
+		g_hash_table_remove (extras->searches, old_key);
+		g_free (old_key);
+	}
+
+	g_hash_table_insert(extras->searches, g_strdup(id), search);
+}
+
+ETableSearchFunc
+e_table_extras_get_search  (ETableExtras *extras,
+			    char         *id)
+{
+	return g_hash_table_lookup(extras->searches, id);
 }
 
 void
