@@ -1,9 +1,35 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* 
+ * e-table-sort-info.h
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ */
+
 #ifndef _E_TABLE_SORT_INFO_H_
 #define _E_TABLE_SORT_INFO_H_
 
 #include <gtk/gtkobject.h>
-#include <gnome-xml/tree.h>
+#include <libxml/tree.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
 
 #define E_TABLE_SORT_INFO_TYPE        (e_table_sort_info_get_type ())
 #define E_TABLE_SORT_INFO(o)          (GTK_CHECK_CAST ((o), E_TABLE_SORT_INFO_TYPE, ETableSortInfo))
@@ -29,6 +55,8 @@ typedef struct {
 	guint frozen : 1;
 	guint sort_info_changed : 1;
 	guint group_info_changed : 1;
+
+	guint can_group : 1;
 } ETableSortInfo;
 
 typedef struct {
@@ -71,5 +99,12 @@ void              e_table_sort_info_load_from_node      (ETableSortInfo   *info,
 xmlNode          *e_table_sort_info_save_to_node        (ETableSortInfo   *info,
 							 xmlNode          *parent);
 ETableSortInfo   *e_table_sort_info_duplicate           (ETableSortInfo   *info);
+void              e_table_sort_info_set_can_group       (ETableSortInfo   *info,
+							 gboolean          can_group);
+gboolean          e_table_sort_info_get_can_group       (ETableSortInfo   *info);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* _E_TABLE_SORT_INFO_H_ */
