@@ -21,13 +21,11 @@
  * 02111-1307, USA.
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
 #include <stdlib.h>
 #include <string.h>
-
+#include <gtk/gtksignal.h>
+#include <gtk/gtkobject.h>
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 #include "gal/util/e-util.h"
@@ -35,25 +33,14 @@
 #include "e-table-state.h"
 
 
+#define PARENT_TYPE (gtk_object_get_type())
+
 #define STATE_VERSION 0.1
 
-static GObjectClass *etst_parent_class;
+static GtkObjectClass *etst_parent_class;
 
 static void
-etst_dispose (GObject *object)
-{
-	ETableState *etst = E_TABLE_STATE (object);
-
-	if (etst->sort_info) {
-		g_object_unref (etst->sort_info);
-		etst->sort_info = NULL;
-	}
-
-	G_OBJECT_CLASS (etst_parent_class)->dispose (object);
-}
-	
-static void
-etst_finalize (GObject *object)
+etst_destroy (GtkObject *object)
 {
 	ETableState *etst = E_TABLE_STATE (object);
 
@@ -67,32 +54,40 @@ etst_finalize (GObject *object)
 		etst->expansions = NULL;
 	}
 	
-	G_OBJECT_CLASS (etst_parent_class)->finalize (object);
+	if (etst->sort_info) {
+		gtk_object_unref (GTK_OBJECT (etst->sort_info));
+		etst->sort_info = NULL;
+	}
+	
+	GTK_OBJECT_CLASS (etst_parent_class)->destroy (object);
 }
 
 static void
-etst_class_init (GObjectClass *klass)
+etst_class_init (GtkObjectClass *klass)
 {
-	etst_parent_class = g_type_class_peek_parent (klass);
+	etst_parent_class = gtk_type_class (PARENT_TYPE);
 	
-	klass->dispose = etst_dispose;
-	klass->finalize = etst_finalize;
+	klass->destroy = etst_destroy;
 }
 
 static void
 etst_init (ETableState *state)
 {
+	GTK_OBJECT_UNSET_FLAGS (GTK_OBJECT (state), GTK_FLOATING);
+
 	state->columns = NULL;
 	state->expansions = NULL;
 	state->sort_info = e_table_sort_info_new();
 }
 
-E_MAKE_TYPE(e_table_state, "ETableState", ETableState, etst_class_init, etst_init, G_TYPE_OBJECT)
+E_MAKE_TYPE(e_table_state, "ETableState", ETableState, etst_class_init, etst_init, PARENT_TYPE)
 
 ETableState *
 e_table_state_new (void)
 {
-	return (ETableState *) g_object_new (E_TABLE_STATE_TYPE, NULL);
+	ETableState *etst = gtk_type_new (E_TABLE_STATE_TYPE);
+
+	return (ETableState *) etst;
 }
 
 ETableState *
@@ -120,10 +115,6 @@ e_table_state_load_from_file    (ETableState *state,
 				 const char          *filename)
 {
 	xmlDoc *doc;
-
-	if (!g_file_test (filename, G_FILE_TEST_EXISTS))
-		return FALSE;
-
 	doc = xmlParseFile (filename);
 	if (doc) {
 		xmlNode *node = xmlDocGetRootElement(doc);
@@ -165,7 +156,7 @@ e_table_state_load_from_node (ETableState *state,
 		node, "state-version", STATE_VERSION);
 
 	if (state->sort_info)
-		g_object_unref (state->sort_info);
+		gtk_object_unref (GTK_OBJECT(state->sort_info));
 
 	state->sort_info = NULL;
 	children = node->xmlChildrenNode;
@@ -209,15 +200,10 @@ e_table_state_save_to_file      (ETableState *state,
 				 const char          *filename)
 {
 	xmlDoc *doc;
-	
-	if ((doc = xmlNewDoc ("1.0")) == NULL)
-		return;
-	
-	xmlDocSetRootElement (doc, e_table_state_save_to_node (state, NULL));
-	
-	e_xml_save_file (filename, doc);
-	
-	xmlFreeDoc (doc);
+	doc = xmlNewDoc("1.0");
+	xmlDocSetRootElement(doc, e_table_state_save_to_node(state, NULL));
+	xmlSaveFile(filename, doc);
+	xmlFreeDoc(doc);
 }
 
 char *
