@@ -79,7 +79,7 @@ E_MAKE_TYPE(color_group,
 	    ColorGroup,
 	    color_group_class_init,
 	    color_group_init,
-	    PARENT_TYPE);
+	    PARENT_TYPE)
 
 
 /* Hash table used to ensure unicity in newly created names*/
