@@ -55,7 +55,7 @@ static GtkObjectClass *parent_class;
 /* The arguments we take */
 enum {
 	ARG_0,
-	ARG_ECML,
+	ARG_ECML
 };
 
 static void
@@ -196,10 +196,10 @@ static char *list [] = {
 #endif
 
 #define SPEC "<ETableSpecification cursor-mode=\"line\" draw-grid=\"false\" draw-focus=\"true\" selection-mode=\"browse\" no-headers=\"true\""		\
-	     " click-to-add=\"true\" _click-to-add-message=\"* Click here to add a category *\">"							\
+             " gettext-domain=\"" E_I18N_DOMAIN "\" click-to-add=\"true\" _click-to-add-message=\"* Click here to add a category *\">"			\
 		"<ETableColumn model_col= \"0\" _title=\"Category\" expansion=\"1.0\" resizable=\"true\" minimum_width=\"24\" cell=\"string\" compare=\"string\"/>" \
 			"<ETableState> <column source=\"0\"/>"												\
-				"<grouping> <leaf column=\"0\" ascending=\"true\"/> </grouping>"								\
+				"<grouping> <leaf column=\"0\" ascending=\"true\"/> </grouping>"							\
 			"</ETableState>"														\
 	     "</ETableSpecification>"
 
@@ -319,4 +319,4 @@ e_categories_master_list_dialog_raise (ECategoriesMasterListDialog *ecmld)
 		gdk_window_raise (dialog->window);
 }
 
-E_MAKE_TYPE(e_categories_master_list_dialog, "ECategoriesMasterListDialog", ECategoriesMasterListDialog, ecmld_class_init, ecmld_init, PARENT_TYPE);
+E_MAKE_TYPE(e_categories_master_list_dialog, "ECategoriesMasterListDialog", ECategoriesMasterListDialog, ecmld_class_init, ecmld_init, PARENT_TYPE)
