@@ -1,18 +1,34 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * WidgetPixmapCombo: A pixmap selector combo box
+ * widget-pixmap-combo.c - A pixmap selector combo box
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author:
+ * Authors:
  *   Jody Goldberg <jgoldberg@home.com>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
+
 #include <config.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-preferences.h>
 #include "gtk-combo-box.h"
 #include "widget-pixmap-combo.h"
+#include "gal/util/e-util.h"
 
 #define PIXMAP_PREVIEW_WIDTH 15
 #define PIXMAP_PREVIEW_HEIGHT 15
@@ -22,7 +38,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint pixmap_combo_signals [LAST_SIGNAL] = { 0, };
+static guint pixmap_combo_signals [LAST_SIGNAL] = { 0, };
 static GtkObjectClass *pixmap_combo_parent_class;
 
 /***************************************************************************/
@@ -32,9 +48,10 @@ pixmap_combo_destroy (GtkObject *object)
 {
 	PixmapCombo *pc = PIXMAP_COMBO (object);
 
-	gtk_object_unref (GTK_OBJECT (pc->tool_tip));
+	if (pc->tool_tip)
+		gtk_object_unref (GTK_OBJECT (pc->tool_tip));
+	pc->tool_tip = NULL;
 	
-	g_free (pc->pixmaps);
 	(*pixmap_combo_parent_class->destroy) (object);
 }
 
@@ -49,12 +66,12 @@ pixmap_combo_class_init (GtkObjectClass *object_class)
 		gtk_signal_new (
 			"changed",
 			GTK_RUN_LAST,
-			object_class->type,
+			E_OBJECT_CLASS_TYPE (object_class),
 			GTK_SIGNAL_OFFSET (PixmapComboClass, changed),
 			gtk_marshal_NONE__INT,
 			GTK_TYPE_NONE, 1, GTK_TYPE_INT);
 
-	gtk_object_class_add_signals (object_class, pixmap_combo_signals, LAST_SIGNAL);
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, pixmap_combo_signals, LAST_SIGNAL);
 }
 
 GtkType
@@ -100,6 +117,15 @@ pixmap_clicked (GtkWidget *button, PixmapCombo *pc)
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (pc));
 }
 
+static GtkWidget *
+image_from_data (guint8 const *data)
+{
+	GdkPixbuf *pixbuf = gdk_pixbuf_new_from_inline (-1,  data, FALSE, NULL);
+	GtkWidget *image = gtk_image_new_from_pixbuf (pixbuf);
+	g_object_unref (pixbuf);
+	return image;
+}
+
 static void
 pixmap_table_setup (PixmapCombo *pc)
 {
@@ -107,31 +133,29 @@ pixmap_table_setup (PixmapCombo *pc)
 
 	pc->combo_table = gtk_table_new (pc->cols, pc->rows, 0);
 	pc->tool_tip = gtk_tooltips_new ();
-	pc->pixmaps = g_malloc (sizeof (GnomePixmap *) * pc->cols * pc->rows);
+	gtk_object_ref (GTK_OBJECT (pc->tool_tip));
+	gtk_object_sink (GTK_OBJECT (pc->tool_tip));
 
 	for (row = 0; row < pc->rows; row++) {
 		for (col = 0; col < pc->cols; ++col, ++index) {
 			PixmapComboElement const *element = pc->elements + index;
 			GtkWidget *button;
 
-			if (element->xpm_data == NULL) {
+			if (element->inline_gdkpixbuf == NULL) {
 				/* exit both loops */
 				row = pc->rows;
 				break;
 			}
 
-			pc->pixmaps[index] = GNOME_PIXMAP (
-			       gnome_pixmap_new_from_xpm_d (element->xpm_data));
-
 			button = gtk_button_new ();
-			gtk_button_set_relief (GTK_BUTTON (button),
-					       GTK_RELIEF_NONE);
 			gtk_container_add (GTK_CONTAINER (button),
-					   GTK_WIDGET (pc->pixmaps[index]));
+				image_from_data (element->inline_gdkpixbuf));
+			gtk_button_set_relief (GTK_BUTTON (button),
+				GTK_RELIEF_NONE);
 			gtk_tooltips_set_tip (pc->tool_tip,
-					      button,
-					      gettext (element->untranslated_tooltip),
-					      "What goes here ??");
+				button,
+				gettext (element->untranslated_tooltip),
+				"What goes here ??");
 
 			gtk_table_attach (GTK_TABLE (pc->combo_table), button,
 					  col, col+1, row+1, row+2, GTK_FILL, GTK_FILL, 1, 1);
@@ -161,12 +185,9 @@ pixmap_combo_construct (PixmapCombo *pc,
 	pixmap_table_setup (pc);
 
 	pc->preview_button = gtk_button_new ();
-	if (!gnome_preferences_get_toolbar_relief_btn ())
-		gtk_button_set_relief (GTK_BUTTON (pc->preview_button), GTK_RELIEF_NONE);
-	if (!gnome_preferences_get_toolbar_relief_btn ())
-		gtk_combo_box_set_arrow_relief (GTK_COMBO_BOX (pc), GTK_RELIEF_NONE);
+	gtk_button_set_relief (GTK_BUTTON (pc->preview_button), GTK_RELIEF_NONE);
 
-	pc->preview_pixmap = gnome_pixmap_new_from_xpm_d (elements [0].xpm_data);
+	pc->preview_pixmap = image_from_data (elements [0].inline_gdkpixbuf);
 
 	gtk_container_add (GTK_CONTAINER (pc->preview_button), GTK_WIDGET (pc->preview_pixmap));
 	gtk_widget_set_usize (GTK_WIDGET (pc->preview_pixmap), 24, 24);
@@ -211,7 +232,8 @@ pixmap_combo_select_pixmap (PixmapCombo *pc, int index)
 		GTK_CONTAINER (pc->preview_button),
 		pc->preview_pixmap);
 
-	pc->preview_pixmap = gnome_pixmap_new_from_xpm_d (pc->elements [index].xpm_data);
+	pc->preview_pixmap = image_from_data (
+		pc->elements [index].inline_gdkpixbuf);
 	gtk_widget_show (pc->preview_pixmap);
 	
 	gtk_container_add (
